@@ -28,7 +28,7 @@ has pubsub => sub {
   return $pubsub;
 };
 
-our $VERSION = '2.30';
+our $VERSION = '2.31';
 
 sub db {
   my $self = shift;
@@ -46,7 +46,7 @@ sub from_string {
   return $self unless $str;
   my $url = Mojo::URL->new($str);
   croak qq{Invalid PostgreSQL connection string "$str"}
-    unless $url->protocol eq 'postgresql';
+    unless $url->protocol =~ /^postgres(?:ql)?$/;
 
   # Connection information
   my $db = $url->path->parts->[0];
@@ -416,8 +416,8 @@ Parse configuration from connection string.
   # Username and database
   $pg->from_string('postgresql://sri@/db2');
 
-  # Username, password, host and database
-  $pg->from_string('postgresql://sri:s3cret@localhost/db3');
+  # Short scheme, username, password, host and database
+  $pg->from_string('postgres://sri:s3cret@localhost/db3');
 
   # Username, domain socket and database
   $pg->from_string('postgresql://sri@%2ftmp%2fpg.sock/db4');
@@ -471,6 +471,8 @@ In alphabetical order:
 
 Dan Book
 
+Flavio Poletti
+
 Hernan Lopes
 
 William Lindley
